# ![logo](/docs/images/annoyance.logo.svg)

[![PyPI pyversions](https://img.shields.io/pypi/pyversions/annoyance.svg)](https://pypi.python.org/pypi/annoyance/)
[![PyPI version](https://badge.fury.io/py/annoyance.svg)](https://badge.fury.io/py/annoyance)
[![Documentation Status](https://readthedocs.org/projects/annoyance/badge/?version=latest)](https://annoyance.readthedocs.io/en/latest/?badge=latest)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)

### [**annoy**](https://github.com/spotify/annoy) for the **an**notation of **ce**ll types. 
**Annoyance** is a simple API for classifying cell types as annotated in an **`adata.obs`** table. 

### Installation

```BASH
pip install annoyance
```

#### To install the development version

```BASH
git clone https://github.com/mvinyard/annoyance.git

cd ./annoyance/
pip install -e .
```

### Notes

This project uses open-source code from [**spotify/annoy**](https://github.com/spotify/annoy). However, **this repo is in no way affiliated with Spotify**. 

Interested? Questions and discussion may be directed to [**Michael Vinyard**](https://github.com/mvinyard) at: [mvinyard@broadinstitute.org](mailto:mvinyard@broadinstitute.org). 
